# `dm2gym`: Convert DeepMind Control Suite to OpenAI gym environments.

This repository contains a lightweight wrapper to convert DeepMind Control Suite to OpenAI gym environments. 

# Installation


# What's new

- 2019-04-14 (v0.1.0)
    - Initial release

# Reference
Please use this bibtex if you want to cite this repository in your publications:
    
    @misc{dm2gym,
          author = {Zuo, Xingdong},
          title = {dm2gym: Convert DeepMind Control Suite to OpenAI gym environments.},
          year = {2019},
          publisher = {GitHub},
          journal = {GitHub repository},
          howpublished = {\url{https://github.com/zuoxingdong/dm2gym}},
        }
